@@ -2,33 +2,37 @@ __all__ = ('LoanIssuePoint', 'LoanPaymentBodyPoint', 'LoanInterestsChargePoint',
 
 from expressmoney.api import *
 from expressmoney.api.accounting.balances import *
-from expressmoney.api.loans import LoanPoint
 
-SERVICE_NAME = 'accounting'
+SERVICE = 'accounting'
 
 
-class LoanIssueCreateContract(Contract):
+class OperationContract(Contract):
     amount = serializers.DecimalField(max_digits=16, decimal_places=0, min_value=1, max_value=1000000000)
+    is_reverse = serializers.BooleanField(default=False)
     department = serializers.IntegerField(min_value=1)
     analytical = serializers.IntegerField(min_value=1)
 
 
-class LoanPaymentBodyCreateContract(LoanIssueCreateContract):
+class LoanIssueCreateContract(OperationContract):
     pass
 
 
-class LoanInterestsChargeCreateContract(LoanIssueCreateContract):
+class LoanPaymentBodyCreateContract(OperationContract):
     pass
 
 
-class LoanPaymentInterestsCreateContract(LoanIssueCreateContract):
+class LoanInterestsChargeCreateContract(OperationContract):
     pass
 
 
-accounting_operations_loan_issue = ID(SERVICE_NAME, 'operations', 'loan_issue')
-accounting_operations_loan_payment_body = ID(SERVICE_NAME, 'operations', 'loan_payment_body')
-accounting_operations_loan_interests_charge = ID(SERVICE_NAME, 'operations', 'loan_interests_charge')
-accounting_operations_loan_payment_interests = ID(SERVICE_NAME, 'operations', 'loan_payment_interests')
+class LoanPaymentInterestsCreateContract(OperationContract):
+    pass
+
+
+accounting_operations_loan_issue = ID(SERVICE, 'operations', 'loan_issue')
+accounting_operations_loan_payment_body = ID(SERVICE, 'operations', 'loan_payment_body')
+accounting_operations_loan_interests_charge = ID(SERVICE, 'operations', 'loan_interests_charge')
+accounting_operations_loan_payment_interests = ID(SERVICE, 'operations', 'loan_payment_interests')
 
 
 class LoanIssuePoint(CreatePointMixin, ContractPoint):
@@ -77,19 +81,3 @@ class LoanPaymentInterestsPoint(CreatePointMixin, ContractPoint):
         loan = self._payload.get('analytical')
         related_points.append(P48809BalanceAnalyticalPoint(self._user, loan))
         return related_points
-
-
-"""
-from django.contrib.auth import get_user_model
-User = get_user_model()
-user = User.objects.get(id=1)
-
-from expressmoney.api.accounting import LoanPaymentBodyPoint
-point = p = LoanPaymentBodyPoint(user)
-p.create({
-    "amount": 500,
-    "department": 1,
-    "analytical": 44
-})
-response = p.get_response()
-"""
